<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>Category</name>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
        <source>All Fonts</source>
        <translation>ཡིག་གཟུགས་ཚང་མ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
        <source>System</source>
        <translation>མ་ལག་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
        <source>User</source>
        <translation>སྤྱོད་མཁན་གྱི་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
        <source>Favorites</source>
        <translation>ངའི་ཉར་ཚགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
        <source>Active</source>
        <translation>སྐུལ་སློང་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
        <source>Chinese</source>
        <translation>རྒྱ་ཡིག་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
        <source>Monospaced</source>
        <translation>ཞེང་མཚུངས་ཡིག་གཟུགས།</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་བསུབ་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་བསུབ་སྲིད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་འགོ་བསླང་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་འགོ་སློང་སྲིད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་བཀོལ་མི་ཆོག་པ་བཟོས་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་བཀོལ་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
        <source>Enable</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སྤྱོད་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
        <source>Disable</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
        <source>Apply to all selected font families</source>
        <translation>བདམས་ཡོད་པའི་ཡིག་གཟུགས་ཚང་མར་སྤྱོད་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
        <source>Broken file</source>
        <translation>ཡིག་ཆ་སྐྱོན་ཤོར་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
        <source>Same version installed</source>
        <translation>པར་གཞི་གཅིག་པ་སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
        <source>System Font</source>
        <translation>མ་ལག་ཡིག་གཟུགས།</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
        <source>%1 font installed</source>
        <translation>ཡིག་གཟུགས་%1སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
        <source>%1 fonts installed</source>
        <translation>ཡིག་གཟུགས་%1སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། ཡིག་ཆ་%1 སྒྲིག་འཇུག་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། ཡིག་ཆ་%1 སྒྲིག་འཇུག་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
        <source>Fonts</source>
        <translation>ཡིག་གཟུགས།</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
        <source>Broken file</source>
        <translation>ཡིག་ཆ་སྐྱོན་ཤོར་ཟིན།</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
        <source>This font will not be available to applications</source>
        <translation>སུབ་རྗེས་ཡིག་གཟུགས་འདི་ཉེར་སྤྱོད་བྱ་རིམ་གཞན་ལ་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
        <source>These fonts will not be available to applications</source>
        <translation>སུབ་རྗེས་ཡིག་གཟུགས་འདི་དག་ཉེར་སྤྱོད་བྱ་རིམ་གཞན་དག་ལ་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>མ་ལག་ཡིག་གཟུགས་གཞན་དག་%1སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
        <source>The font "%1" in use cannot be deleted</source>
        <translation>ད་ལྟ་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་%1སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
        <translation>མ་ལག་ཡིག་གཟུགས་གཞན་དག་%1དང་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་%2སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>ཁྱེད་ཀྱིས་ཡིག་གཟུགས%1འདི་དག་སུབ་རྒྱུ་གཏན་འཁེལ་(ལམ)། </translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
        <source>Deleting fonts, please wait...</source>
        <translation>ཡིག་གཟུགས་སུབ་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
        <source>Font Verification</source>
        <translation>ཡིག་གཟུགས་ར་སྤྲོད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
        <source>No fonts to be installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱེད་རུང་བའི་ཡིག་གཟུགས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
        <source>Exit</source>
        <translation>ཕྱིར་འབུད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
        <source>Continue</source>
        <translation>མུ་མཐུད།</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
        <source>Don't let your dreams be dreams</source>
        <translation>ཕུགས་འདུན་ཡོད་པས་གསར་ཐོན་བྱུང་། འགན་འཁྲི་ཡོད་པས་འཚར་ལོངས་བྱུང་།</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
        <source>Basic info</source>
        <translation>གཞི་རྩའི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
        <source>Style</source>
        <translation>དཔེ་དབྱིབས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
        <source>Type</source>
        <translation>རིགས་གྲས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
        <source>Version</source>
        <translation>པར་གཞི།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
        <source>Description</source>
        <translation>ཞིབ་བརྗོད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
        <source>Unknown</source>
        <translation>མི་ཤེས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
        <source>Full name</source>
        <translation>མིང་ཆ་ཚང་།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
        <source>Ps name</source>
        <translation>PSམིང་།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
        <source>Trademark</source>
        <translation>ཚོང་རྟགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
        <source>Copyright</source>
        <translation>གྲྱོད་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
        <source>License Description</source>
        <translation>གྲྱོད་ཆོག་གི་སྒྲོན་ཆོག</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="60"/>
        <source>Font Manager</source>
        <translation>ཡིག་གཟུགས་དོ་དམ་ཆས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="61"/>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>ཡིག་གཟུགས་དོ་དམ་ཆས་ནི་སྤྱོད་མཁན་གྱི་ཡིག་གཟུགས་སྒྲིག་སྦྱོར་དང་དོ་དམ་ལ་རོགས་རམ་བྱེད་པའི་ཡོ་བྱད་ཅིག་རེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
        <source>Loading fonts, please wait...</source>
        <translation>ཡིག་གཟུགས་འཇུག་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
        <source>The font exported to your desktop</source>
        <translation>ཡིག་གཟུགས་འདི་ཅོག་ངོས་སུ་ཕྱིར་འདྲེན་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
        <source>%1 fonts exported to your desktop</source>
        <translation>ཡིག་གཟུགས་%1ཅོག་ངོས་སུ་ཕྱིར་འདྲེན་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་ལྡང་བས། ཡིག་ཆ་1ཕྱིར་འདྲེན་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་ལྡང་བས། ཡིག་ཆ་%1ཕྱིར་འདྲེན་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
        <source>Add font</source>
        <translation>ཡིག་གཟུགས་སྣོན་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
        <source>Enable</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
        <source>Disable</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
        <source>Delete</source>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་མི་བྱེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
        <source>Details</source>
        <translation>ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
        <source>Display in file manager</source>
        <translation>ཡིག་ཆ་དོ་དམ་ཆས་ཁྲོད་དུ་འཆར་བ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
        <source>Export</source>
        <translation>ཡིག་གཟུགས་ཕྱིར་འདྲེན་པ།</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
        <source>deactivated</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
        <source>The fonts have been deactivated</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1སྤྱོད་བཞིན་ཡོད་པས། སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>མ་ལག་ཡིག་གཟུགས་དང་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
        <source>You cannot disable system fonts</source>
        <translation>མ་ལག་ཡིག་གཟུགས་སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
        <source>Install Font</source>
        <translation>ཡིག་གཟུགས་སྒྲིག་སྦྱོར།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
        <source>Verifying...</source>
        <translation>ར་སྤྲོད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
        <source>Unknown</source>
        <translation>མི་ཤེས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
        <source>Broken file</source>
        <translation>ཡིག་ཆ་སྐྱོན་ཤོར་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
        <source>Installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
        <source>Not Installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
        <source>Install Font</source>
        <translation>ཡིག་གཟུགས་སྒྲིག་སྦྱོར།</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
        <source>No search results</source>
        <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
        <source>No fonts</source>
        <translation>ཡིག་གཟུགས་མེད།</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
        <source>Help</source>
        <translation>རོགས་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་འཆར་བ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
        <source>Page up</source>
        <translation>ཤོག་ངོས་གོང་མ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
        <source>Page down</source>
        <translation>ཤོག་ངོས་རྗེས་མ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
        <source>Add font</source>
        <translation>ཡིག་གཟུགས་སྣོན་པ།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་མི་བྱེད།</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
        <source>Font info</source>
        <translation>ཡིག་གཟུགས་ཆ་འཕྲིན།</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
        <source>Input preview text</source>
        <translation>ཡིག་ཆའི་ནང་དོན་འཇུག་ནས་སྔོན་འཆར་བྱེད་པ།</translation>
    </message>
</context>
</TS>
